---
description: >-
  If you see things like 'NACF' and have no idea what this is, your in the right
  place
---

# 🔑 Abbreviation Key

<figure><img src="../../../../.gitbook/assets/call_flow.jpg" alt=""><figcaption><p>Example of Call Flow showing abbreviations.</p></figcaption></figure>

| Abbreviation | Meaning                           |
| ------------ | --------------------------------- |
| CFB          | Call Forward Busy                 |
| CFNR         | Call Forward Not Reachable        |
| CFA          | Call Forward Always               |
| OF           | Overflow                          |
| NACF         | No Answer Call Forward            |
| BCT          | Bounced Call Transfer             |
| SCF          | Stranded Calls Transfer           |
| USCF         | Unavailable Stranded Call Tranfer |

